const { main:Main } = imports.ui;
const { St, Clutter, Pango } = imports.gi;

const ExtensionUtils = imports.misc.extensionUtils;
const Self = ExtensionUtils.getCurrentExtension();


// I use object pattern as main extension, but i avoid to use "this" to make this extension didn't
// increase memory usage
class Extension {
    constructor() { }

    // Nothing we do on enable() method. it started on disable() method
    enable() { }

    // Extension starts here
    disable() {
        // Settings schema
        let settings = ExtensionUtils.getSettings();
        // Run only when current session mode is in "unlock-dialog"
        if (Main.sessionMode.currentMode == 'unlock-dialog') {
            // Clock stack from screenShield
            let clockStack = Main.screenShield._dialog._clock;

            // Message Label
            let message = new St.Label({
                text: settings.get_string('message'),
                x_align: Clutter.ActorAlign.CENTER,
                opacity: 255 * 0.6, // A bit low of opacity
                width: 320 // Recommended size
            });
            // Set clutter text from message
            message.clutter_text.set({
                line_alignment: Pango.Alignment.CENTER,
                line_wrap: true,
                line_wrap_mode: Pango.WrapMode.WORD,
            });
            // Append above date label from clockStack
            clockStack.insert_child_above(message, clockStack._date);

            // Remove used padding top of lock hint with message height
            clockStack._hint.set({
                style: `padding-top: ${(message.height >= 48 ? 0 : 48 - message.height)}px;`,
            });
        }
        // When user unlocks the screen, the message will automatically destroyed by unlockDialog
    }
}

function init() { return new Extension(); }